APITokenCost class
Constructors
- APITokenCost({required DateTime date, required int completionTokens, required int promptTokens})
- Returns a new APITokenCost instance.
Properties
- completionTokens ↔ int
-
getter/setter pair
- date ↔ DateTime
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- promptTokens ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → APITokenCost? -
Returns a new APITokenCost instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< APITokenCost> -
mapFromJson(
dynamic json) → Map< String, APITokenCost> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< APITokenCost> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.