ActiveUsersData class

Constructors

ActiveUsersData({required String username, required String name, required double engagementIndex, required double performanceIndex})
Returns a new ActiveUsersData instance.

Properties

engagementIndex double
Engagement index
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
learner name
getter/setter pair
performanceIndex double
Performance index
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
learner username
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ActiveUsersData?
Returns a new ActiveUsersData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ActiveUsersData>
mapFromJson(dynamic json) Map<String, ActiveUsersData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ActiveUsersData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.