aiBotV1BotsBotRetrieve method
Create modify and update bot information for a specific tenant.
Parameters:
Implementation
Future<Bot?> aiBotV1BotsBotRetrieve(int id, String org,) async {
final response = await aiBotV1BotsBotRetrieveWithHttpInfo(id, org,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Bot',) as Bot;
}
return null;
}