aiMathMathSampleQuestionsDestroy method

Future<void> aiMathMathSampleQuestionsDestroy(
  1. int id,
  2. String org
)

Upload documents to provide sample questions of reference to generate more math questions from.

Parameters:

  • int id (required): A unique integer value identifying this sample questions document.

  • String org (required):

Implementation

Future<void> aiMathMathSampleQuestionsDestroy(int id, String org,) async {
  final response = await aiMathMathSampleQuestionsDestroyWithHttpInfo(id, org,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
}