aiMentorOrgsSessionsAskCreate method

Future<AskMentorResponse?> aiMentorOrgsSessionsAskCreate(
  1. String org,
  2. String sessionId, {
  3. AskMentorRequest? askMentorRequest,
})

Send a custom json from langflow to answer a question

Parameters:

Implementation

Future<AskMentorResponse?> aiMentorOrgsSessionsAskCreate(String org, String sessionId, { AskMentorRequest? askMentorRequest, }) async {
  final response = await aiMentorOrgsSessionsAskCreateWithHttpInfo(org, sessionId,  askMentorRequest: askMentorRequest, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'AskMentorResponse',) as AskMentorResponse;

  }
  return null;
}