aiMentorOrgsUsersSessionsDownloadSessionRetrieve method
View to add the downloadable message for a session
Parameters:
Implementation
Future<ChatHistoryItem?> aiMentorOrgsUsersSessionsDownloadSessionRetrieve(String org, String sessionId, String userId,) async {
final response = await aiMentorOrgsUsersSessionsDownloadSessionRetrieveWithHttpInfo(org, sessionId, userId,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'ChatHistoryItem',) as ChatHistoryItem;
}
return null;
}