AskMentorRequest class

Constructors

AskMentorRequest({String? prompt, String? name, String? org, Object? mentorFlow, String? sessionId, String llmProvider = 'google', bool returnResources = false})
Returns a new AskMentorRequest instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
llmProvider String
The LLM provider. Google by default, could be 'google' or 'openai'.
getter/setter pair
mentorFlow Object?
Mentor flow from langchain
getter/setter pair
name String?
Mentor name
getter/setter pair
org String?
Organization name
getter/setter pair
prompt String?
Message to ask the mentor
getter/setter pair
returnResources bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
Session id for the mentor. Required for chat history
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AskMentorRequest?
Returns a new AskMentorRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AskMentorRequest>
mapFromJson(dynamic json) Map<String, AskMentorRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AskMentorRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.