Assertions class

Constructors

Assertions({required int id, required String user, required DateTime created, required DateTime updated, required String entityId, required int credential, Object? metadata, DateTime? issuedOn, bool? revoked, String? revocationReason, DateTime? expiresAt, bool? hashed, String? salt, String? narrative, AcceptanceEnum? acceptance, int? item})
Returns a new Assertions instance.

Properties

acceptance AcceptanceEnum?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
created DateTime
getter/setter pair
credential int
getter/setter pair
entityId String
getter/setter pair
expiresAt DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
hashed bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
id int
getter/setter pair
issuedOn DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
item int?
getter/setter pair
metadata Object?
getter/setter pair
narrative String?
getter/setter pair
revocationReason String?
getter/setter pair
revoked bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt String?
getter/setter pair
updated DateTime
getter/setter pair
user String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Assertions?
Returns a new Assertions instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Assertions>
mapFromJson(dynamic json) Map<String, Assertions>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Assertions>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.