audienceOrgsActiveUsersPerCourseRetrieve method

Future<ActiveUsersPerCourse?> audienceOrgsActiveUsersPerCourseRetrieve(
  1. String org, {
  2. String? endDate,
  3. String? format,
  4. int? groupId,
  5. String? startDate,
})

Count of users with known activity within specified date_range on a per-course basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 Default result when no query param is added is last_7_days (today inclusive)

Parameters:

  • String org (required):

  • String endDate: end date. ISO 8601

  • String format: Format * json - json

  • int groupId: Cohort Group ID

  • String startDate: start date. ISO 8601

Implementation

Future<ActiveUsersPerCourse?> audienceOrgsActiveUsersPerCourseRetrieve(String org, { String? endDate, String? format, int? groupId, String? startDate, }) async {
  final response = await audienceOrgsActiveUsersPerCourseRetrieveWithHttpInfo(org,  endDate: endDate, format: format, groupId: groupId, startDate: startDate, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'ActiveUsersPerCourse',) as ActiveUsersPerCourse;

  }
  return null;
}