audienceOrgsRegisteredUsersPerCourseRetrieve method

Future<Enrollments?> audienceOrgsRegisteredUsersPerCourseRetrieve(
  1. String org, {
  2. String? active,
  3. String? endDate,
  4. String? format,
  5. int? groupId,
  6. int? length,
  7. int? page,
  8. String? startDate,
})

Aggregated count of active/inactive enrollments on a per course basis Query Params active e.g true/false would mean not active enrollments

Parameters:

  • String org (required):

  • String active: Any of y, yes, true. set to false or no for unenrollments * y - y * yes - yes * true - true * True - True * n - n * no - no * false - false * False - False

  • String endDate: end date. ISO 8601

  • String format: Format * json - json

  • int groupId: Cohort Group ID

  • int length: Size of data to return

  • int page: Page offset

  • String startDate: start date. ISO 8601

Implementation

Future<Enrollments?> audienceOrgsRegisteredUsersPerCourseRetrieve(String org, { String? active, String? endDate, String? format, int? groupId, int? length, int? page, String? startDate, }) async {
  final response = await audienceOrgsRegisteredUsersPerCourseRetrieveWithHttpInfo(org,  active: active, endDate: endDate, format: format, groupId: groupId, length: length, page: page, startDate: startDate, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Enrollments',) as Enrollments;

  }
  return null;
}