coreUsersSearchRetrieve method

Future<UserSearchViewGetResponse?> coreUsersSearchRetrieve({
  1. int? page,
  2. int? pageSize,
  3. String? query,
  4. String? sort,
})

Retrieve users based on query Not intended for public use with multitenant platforms Params: query sort

Parameters:

Implementation

Future<UserSearchViewGetResponse?> coreUsersSearchRetrieve({ int? page, int? pageSize, String? query, String? sort, }) async {
  final response = await coreUsersSearchRetrieveWithHttpInfo( page: page, pageSize: pageSize, query: query, sort: sort, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'UserSearchViewGetResponse',) as UserSearchViewGetResponse;

  }
  return null;
}