CountData class

Constructors

CountData({required int count})
Returns a new CountData instance.

Properties

count int
Total
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CountData?
Returns a new CountData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CountData>
mapFromJson(dynamic json) Map<String, CountData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CountData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.