CourseGradeDetailBlock class

Constructors

CourseGradeDetailBlock({required String displayName, required String id, required String average, String? attempts})
Returns a new CourseGradeDetailBlock instance.

Properties

attempts String?
Total users who have attempted it
getter/setter pair
average String
Average block value
getter/setter pair
displayName String
Block name
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
Block Id
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CourseGradeDetailBlock?
Returns a new CourseGradeDetailBlock instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CourseGradeDetailBlock>
mapFromJson(dynamic json) Map<String, CourseGradeDetailBlock>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CourseGradeDetailBlock>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.