CredApi class

Constructors

CredApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

credV2AssertionsRetrieve() Future<void>
credV2AssertionsRetrieve2(String entityId) Future<void>
Parameters:
credV2AssertionsRetrieve2WithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'GET /api/cred/v2/assertions/{entity_id}' operation and returns the Response. Parameters:
credV2AssertionsRetrieveWithHttpInfo() Future<Response>
Performs an HTTP 'GET /api/cred/v2/assertions/' operation and returns the Response.
credV2AssertionsUpdate(String entityId) Future<void>
Parameters:
credV2AssertionsUpdateWithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'PUT /api/cred/v2/assertions/{entity_id}' operation and returns the Response. Parameters:
credV2CredentialsAssertionsBulkCreate(String entityId) Future<void>
Parameters:
credV2CredentialsAssertionsBulkCreateWithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'POST /api/cred/v2/credentials/{entity_id}/assertions/bulk/' operation and returns the Response. Parameters:
credV2CredentialsAssertionsCreate(String entityId) Future<void>
Parameters:
credV2CredentialsAssertionsCreateWithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'POST /api/cred/v2/credentials/{entity_id}/assertions/' operation and returns the Response. Parameters:
credV2CredentialsAssertionsRetrieve(String entityId) Future<void>
Parameters:
credV2CredentialsAssertionsRetrieveWithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'GET /api/cred/v2/credentials/{entity_id}/assertions/' operation and returns the Response. Parameters:
credV2CredentialsCreate() Future<void>
credV2CredentialsCreateWithHttpInfo() Future<Response>
Performs an HTTP 'POST /api/cred/v2/credentials/' operation and returns the Response.
credV2CredentialsDestroy(String entityId) Future<void>
Parameters:
credV2CredentialsDestroyWithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'DELETE /api/cred/v2/credentials/{entity_id}' operation and returns the Response. Parameters:
credV2CredentialsRetrieve() Future<void>
credV2CredentialsRetrieve2(String entityId) Future<void>
Parameters:
credV2CredentialsRetrieve2WithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'GET /api/cred/v2/credentials/{entity_id}' operation and returns the Response. Parameters:
credV2CredentialsRetrieveWithHttpInfo() Future<Response>
Performs an HTTP 'GET /api/cred/v2/credentials/' operation and returns the Response.
credV2CredentialsUpdate(String entityId) Future<void>
Parameters:
credV2CredentialsUpdateWithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'PUT /api/cred/v2/credentials/{entity_id}' operation and returns the Response. Parameters:
credV2IssuersAuthorityCreate() Future<void>
credV2IssuersAuthorityCreateWithHttpInfo() Future<Response>
Performs an HTTP 'POST /api/cred/v2/issuers/authority/' operation and returns the Response.
credV2IssuersCreate() Future<void>
credV2IssuersCreateWithHttpInfo() Future<Response>
Performs an HTTP 'POST /api/cred/v2/issuers/' operation and returns the Response.
credV2IssuersDestroy(String entityId) Future<void>
Parameters:
credV2IssuersDestroyWithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'DELETE /api/cred/v2/issuers/{entity_id}' operation and returns the Response. Parameters:
credV2IssuersRetrieve() Future<void>
credV2IssuersRetrieve2(String entityId) Future<void>
Parameters:
credV2IssuersRetrieve2WithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'GET /api/cred/v2/issuers/{entity_id}' operation and returns the Response. Parameters:
credV2IssuersRetrieveWithHttpInfo() Future<Response>
Performs an HTTP 'GET /api/cred/v2/issuers/' operation and returns the Response.
credV2IssuersUpdate(String entityId) Future<void>
Parameters:
credV2IssuersUpdateWithHttpInfo(String entityId) Future<Response>
Performs an HTTP 'PUT /api/cred/v2/issuers/{entity_id}' operation and returns the Response. Parameters:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited