Credential class

Constructors

Credential({required int id, required DateTime created, required DateTime updated, required String entityId, required String name, List<int> items = const [], String? description, String? criteriaUrl, String? criteriaText, int? expiresAmount, CredentialExpiresDuration? expiresDuration, String? iconImage, String? thumbnailImage, String? backgroundImage, CredentialCredentialType? credentialType, Object? tags, bool? public, Object? metadata, String? htmlTemplate, String? cssTemplate, CredentialIssuingSignal? issuingSignal, int? issuer})
Returns a new Credential instance.

Properties

backgroundImage String?
getter/setter pair
created DateTime
getter/setter pair
credentialType CredentialCredentialType?
getter/setter pair
criteriaText String?
getter/setter pair
criteriaUrl String?
getter/setter pair
cssTemplate String?
getter/setter pair
description String?
getter/setter pair
entityId String
getter/setter pair
expiresAmount int?
Minimum value: -2147483648 Maximum value: 2147483647
getter/setter pair
expiresDuration CredentialExpiresDuration?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
htmlTemplate String?
getter/setter pair
iconImage String?
getter/setter pair
id int
getter/setter pair
issuer int?
getter/setter pair
issuingSignal CredentialIssuingSignal?
getter/setter pair
items List<int>
getter/setter pair
metadata Object?
getter/setter pair
name String
getter/setter pair
public bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags Object?
getter/setter pair
thumbnailImage String?
getter/setter pair
updated DateTime
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Credential?
Returns a new Credential instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Credential>
mapFromJson(dynamic json) Map<String, Credential>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Credential>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.