credentialsOrgsAssertionsList method
Endpoint to retrieve the issued credentials for a given tenant
Parameters:
Implementation
Future<PaginatedAssertionsList?> credentialsOrgsAssertionsList(String org, { String? format, int? groupId, int? limit, int? offset, }) async {
final response = await credentialsOrgsAssertionsListWithHttpInfo(org, format: format, groupId: groupId, limit: limit, offset: offset, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'PaginatedAssertionsList',) as PaginatedAssertionsList;
}
return null;
}