credentialsOrgsAssertionsListWithHttpInfo method

Future<Response> credentialsOrgsAssertionsListWithHttpInfo(
  1. String org, {
  2. String? format,
  3. int? groupId,
  4. int? limit,
  5. int? offset,
})

Endpoint to retrieve the issued credentials for a given tenant

Note: This method returns the HTTP Response.

Parameters:

  • String org (required):

  • String format: Format * json - json

  • int groupId: Cohort Group ID

  • int limit: Number of results to return per page.

  • int offset: The initial index from which to return the results.

Implementation

Future<Response> credentialsOrgsAssertionsListWithHttpInfo(String org, { String? format, int? groupId, int? limit, int? offset, }) async {
  // ignore: prefer_const_declarations
  final path = r'/api/credentials/orgs/{org}/assertions/'
    .replaceAll('{org}', org);

  // ignore: prefer_final_locals
  Object? postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  if (format != null) {
    queryParams.addAll(_queryParams('', 'format', format));
  }
  if (groupId != null) {
    queryParams.addAll(_queryParams('', 'group_id', groupId));
  }
  if (limit != null) {
    queryParams.addAll(_queryParams('', 'limit', limit));
  }
  if (offset != null) {
    queryParams.addAll(_queryParams('', 'offset', offset));
  }

  const contentTypes = <String>[];


  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}