credentialsOrgsCourseCredentialsListWithHttpInfo method

Future<Response> credentialsOrgsCourseCredentialsListWithHttpInfo(
  1. String org, {
  2. int? limit,
  3. int? offset,
})

Endpoint to retrieve the credentials of a given tenant

Note: This method returns the HTTP Response.

Parameters:

  • String org (required):

  • int limit: Number of results to return per page.

  • int offset: The initial index from which to return the results.

Implementation

Future<Response> credentialsOrgsCourseCredentialsListWithHttpInfo(String org, { int? limit, int? offset, }) async {
  // ignore: prefer_const_declarations
  final path = r'/api/credentials/orgs/{org}/course-credentials/'
    .replaceAll('{org}', org);

  // ignore: prefer_final_locals
  Object? postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  if (limit != null) {
    queryParams.addAll(_queryParams('', 'limit', limit));
  }
  if (offset != null) {
    queryParams.addAll(_queryParams('', 'offset', offset));
  }

  const contentTypes = <String>[];


  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}