credentialsOrgsList method

Future<PaginatedCredentialList?> credentialsOrgsList(
  1. String org, {
  2. int? limit,
  3. int? offset,
})

Endpoint to retrieve the credentials of a given tenant

Parameters:

  • String org (required):

  • int limit: Number of results to return per page.

  • int offset: The initial index from which to return the results.

Implementation

Future<PaginatedCredentialList?> credentialsOrgsList(String org, { int? limit, int? offset, }) async {
  final response = await credentialsOrgsListWithHttpInfo(org,  limit: limit, offset: offset, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'PaginatedCredentialList',) as PaginatedCredentialList;

  }
  return null;
}