DetailedGradeViewData class

Constructors

DetailedGradeViewData({required String displayName, required String id, List<DetailedGradeSubsection> children = const []})
Returns a new DetailedGradeViewData instance.

Properties

children List<DetailedGradeSubsection>
getter/setter pair
displayName String
Chapter name
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
Chapter Id
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) DetailedGradeViewData?
Returns a new DetailedGradeViewData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<DetailedGradeViewData>
mapFromJson(dynamic json) Map<String, DetailedGradeViewData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<DetailedGradeViewData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.