EngagementApi class

Constructors

EngagementApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

engagementOrgsActivityRetrieve(String org, {String? format, int? groupId, int? length, int? page}) Future<EngagementPerCourse?>
Engagement information on a per-course basis
engagementOrgsActivityRetrieveWithHttpInfo(String org, {String? format, int? groupId, int? length, int? page}) Future<Response>
Engagement information on a per-course basis
engagementOrgsCourseCompletionPerCourseRetrieve(String org, {String? format, int? groupId, int? length, int? page}) Future<CourseCompletionPerCourse?>
Aggregated table of enrollments,and completed count on a per-course basis
engagementOrgsCourseCompletionPerCourseRetrieveWithHttpInfo(String org, {String? format, int? groupId, int? length, int? page}) Future<Response>
Aggregated table of enrollments,and completed count on a per-course basis
engagementOrgsCoursesTimeAverageRetrieve(String courseId, String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<AverageOvertime?>
Average time spent in secs on a per-day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 3. course_id
engagementOrgsCoursesTimeAverageRetrieveWithHttpInfo(String courseId, String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Average time spent in secs on a per-day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 3. course_id
engagementOrgsCoursesTimeDetailRetrieve(String courseId, String org, {String? format, int? groupId}) Future<TimeDetail?>
Time spent per course in secs in a tree like form Kwargs course_id e.g course-v1:Org+Course4+Run Query Params 1. start_date
engagementOrgsCoursesTimeDetailRetrieveWithHttpInfo(String courseId, String org, {String? format, int? groupId}) Future<Response>
Time spent per course in secs in a tree like form Kwargs course_id e.g course-v1:Org+Course4+Run Query Params 1. start_date
engagementOrgsCoursesTimeOverTimeRetrieve(String courseId, String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Overtime?>
Time spent per course in secs on a per-day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 Kwargs 3. course_id Default result when no query param is added is last_7_days (today inclusive)
engagementOrgsCoursesTimeOverTimeRetrieveWithHttpInfo(String courseId, String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Time spent per course in secs on a per-day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 Kwargs 3. course_id Default result when no query param is added is last_7_days (today inclusive)
engagementOrgsCoursesTimeUsersDetailRetrieve(String courseId, String org, String userId, {String? endDate, String? format, int? groupId, String? startDate}) Future<PerLearnerTimeSpentInCourseTree?>
Time spent within a course in ordered hierarchical format Kwargs 1. course_id e.g course-v1:Org+Course4+Run 2. user_id e.g developer@ibleducation.com or dev123 (username|email) Query Params 3. start_date
engagementOrgsCoursesTimeUsersDetailRetrieveWithHttpInfo(String courseId, String org, String userId, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Time spent within a course in ordered hierarchical format Kwargs 1. course_id e.g course-v1:Org+Course4+Run 2. user_id e.g developer@ibleducation.com or dev123 (username|email) Query Params 3. start_date
engagementOrgsCoursesTimeUsersOverTimeRetrieve(String courseId, String org, String userId, {String? endDate, String? format, int? groupId, String? startDate}) Future<Overtime?>
Time spent in secs on a per-day basis Query Params 1. course_id
engagementOrgsCoursesTimeUsersOverTimeRetrieveWithHttpInfo(String courseId, String org, String userId, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Time spent in secs on a per-day basis Query Params 1. course_id
engagementOrgsCoursesTimeUsersRetrieve(String courseId, String org, {String? endDate, String? format, int? groupId, int? length, int? page, String? startDate}) Future<TimeSpentByUsersInCourse?>
Time spent by users in a course Query Params course_id e.g course-v1:Org+Course4+Run
engagementOrgsCoursesTimeUsersRetrieveWithHttpInfo(String courseId, String org, {String? endDate, String? format, int? groupId, int? length, int? page, String? startDate}) Future<Response>
Time spent by users in a course Query Params course_id e.g course-v1:Org+Course4+Run
engagementOrgsCoursesVideosOverTimeRetrieve(String courseId, String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Overtime?>
Watched Videos count on a per-day basis Kwargs 1. course_id
engagementOrgsCoursesVideosOverTimeRetrieveWithHttpInfo(String courseId, String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Watched Videos count on a per-day basis Kwargs 1. course_id
engagementOrgsCoursesVideosRetrieve(String courseId, String org, {String? format, int? groupId}) Future<VideosSpecificCourse?>
Engagement information (video) for a specific course
engagementOrgsCoursesVideosRetrieveWithHttpInfo(String courseId, String org, {String? format, int? groupId}) Future<Response>
Engagement information (video) for a specific course
engagementOrgsCoursesVideosSummaryRetrieve(String courseId, String org, {String? format, int? groupId}) Future<VideosInCourseSummary?>
Returns a Simplified tree structure of videos watched in course Kwargs course_id e.g course-v1:Org+Course4+Run
engagementOrgsCoursesVideosSummaryRetrieveWithHttpInfo(String courseId, String org, {String? format, int? groupId}) Future<Response>
Returns a Simplified tree structure of videos watched in course Kwargs course_id e.g course-v1:Org+Course4+Run
engagementOrgsCoursesVideosUsersRetrieve(String courseId, String org, {String? format, int? groupId}) Future<WatchedVideosPerUser?>
List of users' videos completed records for a specific course Kwargs course_id e.g course-v1:Org+Course4+Run
engagementOrgsCoursesVideosUsersRetrieveWithHttpInfo(String courseId, String org, {String? format, int? groupId}) Future<Response>
List of users' videos completed records for a specific course Kwargs course_id e.g course-v1:Org+Course4+Run
engagementOrgsTimeAveragePerlearnerPercourseRetrieve(String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<AverageOvertime?>
Average time spent by a learner in enrolled courses. Gives a rough estimate of whats the average time that would be spent by a learner in a course Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10
engagementOrgsTimeAveragePerlearnerPercourseRetrieveWithHttpInfo(String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Average time spent by a learner in enrolled courses. Gives a rough estimate of whats the average time that would be spent by a learner in a course Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10
engagementOrgsTimeAverageWithOverTimeRetrieve(String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<AverageOvertime?>
Average time spent in secs on a per-day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 3. course_id
engagementOrgsTimeAverageWithOverTimeRetrieveWithHttpInfo(String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Average time spent in secs on a per-day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 3. course_id
engagementOrgsTimeOverTimeRetrieve(String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<OvertimeWithChangeInfo?>
Time spent in secs on a per-day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 Default result when no query param is added is last_7_days (today inclusive)
engagementOrgsTimeOverTimeRetrieveWithHttpInfo(String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Time spent in secs on a per-day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 Default result when no query param is added is last_7_days (today inclusive)
engagementOrgsTimePerCourseRetrieve(String org, {String? endDate, String? format, int? groupId, int? length, int? page, String? startDate}) Future<TimeSpentPerCourse?>
Aggregated time spent value on a per course basis
engagementOrgsTimePerCourseRetrieveWithHttpInfo(String org, {String? endDate, String? format, int? groupId, int? length, int? page, String? startDate}) Future<Response>
Aggregated time spent value on a per course basis
engagementOrgsVideosOverTimeRetrieve(String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Overtime?>
Watched Videos count on a per-day basis Kwargs 1. course_id
engagementOrgsVideosOverTimeRetrieveWithHttpInfo(String org, {String? endDate, String? format, int? groupId, String? startDate}) Future<Response>
Watched Videos count on a per-day basis Kwargs 1. course_id
engagementOrgsVideosRetrieve(String org, {String? format, int? groupId, int? length, int? page}) Future<VideoEngagementPerCourse?>
Video Engagement information on a per-course basis
engagementOrgsVideosRetrieveWithHttpInfo(String org, {String? format, int? groupId, int? length, int? page}) Future<Response>
Video Engagement information on a per-course basis
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited