engagementOrgsCoursesTimeUsersRetrieve method

Future<TimeSpentByUsersInCourse?> engagementOrgsCoursesTimeUsersRetrieve(
  1. String courseId,
  2. String org, {
  3. String? endDate,
  4. String? format,
  5. int? groupId,
  6. int? length,
  7. int? page,
  8. String? startDate,
})

Time spent by users in a course Query Params course_id e.g course-v1:Org+Course4+Run

Parameters:

  • String courseId (required):

  • String org (required):

  • String endDate: end date. ISO 8601

  • String format: Format * json - json

  • int groupId: Cohort Group ID

  • int length: Size of data to return

  • int page: Page offset

  • String startDate: start date. ISO 8601

Implementation

Future<TimeSpentByUsersInCourse?> engagementOrgsCoursesTimeUsersRetrieve(String courseId, String org, { String? endDate, String? format, int? groupId, int? length, int? page, String? startDate, }) async {
  final response = await engagementOrgsCoursesTimeUsersRetrieveWithHttpInfo(courseId, org,  endDate: endDate, format: format, groupId: groupId, length: length, page: page, startDate: startDate, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'TimeSpentByUsersInCourse',) as TimeSpentByUsersInCourse;

  }
  return null;
}