engagementOrgsTimeAveragePerlearnerPercourseRetrieve method
Average time spent by a learner in enrolled courses. Gives a rough estimate of whats the average time that would be spent by a learner in a course Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10
Parameters:
Implementation
Future<AverageOvertime?> engagementOrgsTimeAveragePerlearnerPercourseRetrieve(String org, { String? endDate, String? format, int? groupId, String? startDate, }) async {
final response = await engagementOrgsTimeAveragePerlearnerPercourseRetrieveWithHttpInfo(org, endDate: endDate, format: format, groupId: groupId, startDate: startDate, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'AverageOvertime',) as AverageOvertime;
}
return null;
}