engagementOrgsTimePerCourseRetrieve method

Future<TimeSpentPerCourse?> engagementOrgsTimePerCourseRetrieve(
  1. String org, {
  2. String? endDate,
  3. String? format,
  4. int? groupId,
  5. int? length,
  6. int? page,
  7. String? startDate,
})

Aggregated time spent value on a per course basis

Parameters:

  • String org (required):

  • String endDate: end date. ISO 8601

  • String format: Format * json - json

  • int groupId: Cohort Group ID

  • int length: Size of data to return

  • int page: Page offset

  • String startDate: start date. ISO 8601

Implementation

Future<TimeSpentPerCourse?> engagementOrgsTimePerCourseRetrieve(String org, { String? endDate, String? format, int? groupId, int? length, int? page, String? startDate, }) async {
  final response = await engagementOrgsTimePerCourseRetrieveWithHttpInfo(org,  endDate: endDate, format: format, groupId: groupId, length: length, page: page, startDate: startDate, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'TimeSpentPerCourse',) as TimeSpentPerCourse;

  }
  return null;
}