EnrollmentsData class
Constructors
- EnrollmentsData({required String courseId, required String name, required int users, required double percentage})
- Returns a new EnrollmentsData instance.
Properties
- courseId ↔ String
-
Edx Course ID
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
Course Name
getter/setter pair
- percentage ↔ double
-
Percentage ...
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- users ↔ int
-
Number of users
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → EnrollmentsData? -
Returns a new EnrollmentsData instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< EnrollmentsData> -
mapFromJson(
dynamic json) → Map< String, EnrollmentsData> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< EnrollmentsData> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.