FinanceApi class

Constructors

FinanceApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

financeOrgsProductsOrdersRetrieve(String org, String slug, {String? endDate, String? startDate}) Future<Order?>
Return list of WooCommerce orders for product slug over optional date range
financeOrgsProductsOrdersRetrieveWithHttpInfo(String org, String slug, {String? endDate, String? startDate}) Future<Response>
Return list of WooCommerce orders for product slug over optional date range
financeOrgsProductsRetrieve(String org) Future<Product?>
Returns table listing products and product info for all or specific org
financeOrgsProductsRetrieveWithHttpInfo(String org) Future<Response>
Returns table listing products and product info for all or specific org
financeOrgsProductsSalesOverTimeRetrieve(String org, String slug, {String? endDate, String? startDate}) Future<NetRevenueOverTime?>
Returns Net Revenue over time for org and slug
financeOrgsProductsSalesOverTimeRetrieveWithHttpInfo(String org, String slug, {String? endDate, String? startDate}) Future<Response>
Returns Net Revenue over time for org and slug
financeOrgsRevenueNetOverTimeRetrieve(String org, {String? endDate, String? startDate}) Future<NetRevenueOverTime?>
Returns Net Revenue over time for org and slug
financeOrgsRevenueNetOverTimeRetrieveWithHttpInfo(String org, {String? endDate, String? startDate}) Future<Response>
Returns Net Revenue over time for org and slug
financeOrgsRevenueProductsRetrieve(String org, {String? endDate, String? startDate}) Future<RevenueByProduct?>
Returns Revenue by Product + summary for specific org
financeOrgsRevenueProductsRetrieveWithHttpInfo(String org, {String? endDate, String? startDate}) Future<Response>
Returns Revenue by Product + summary for specific org
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited