financeOrgsRevenueNetOverTimeRetrieve method

Future<NetRevenueOverTime?> financeOrgsRevenueNetOverTimeRetrieve(
  1. String org, {
  2. String? endDate,
  3. String? startDate,
})

Returns Net Revenue over time for org and slug

Parameters:

  • String org (required):

  • String endDate: End of date range, not-inclusive. ISO8601 Date or DateTime. Dates will have 00:00:00 set as the time.

  • String startDate: Start of date range, not-inclusive. ISO8601 Date or DateTime. Dates will have 00:00:00 set as the time.

Implementation

Future<NetRevenueOverTime?> financeOrgsRevenueNetOverTimeRetrieve(String org, { String? endDate, String? startDate, }) async {
  final response = await financeOrgsRevenueNetOverTimeRetrieveWithHttpInfo(org,  endDate: endDate, startDate: startDate, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'NetRevenueOverTime',) as NetRevenueOverTime;

  }
  return null;
}