LearnerInformationAPIData class

Constructors

LearnerInformationAPIData({required String username, required String name, required String email, required String dateJoined, required String lastActivity, int? totalAssessments, int? totalTimeSpent, int? totalVideos, int? courseCompletions, Map<String, Object> timeSpentOvertime = const {}, String? continent, String? continentCode, String? country, String? countryCode, String? region, String? regionCode, String? location, String? city, String? browser, String? operatingSystem, String? resolution})
Returns a new LearnerInformationAPIData instance.

Properties

browser String?
last known browser
getter/setter pair
city String?
last location - city
getter/setter pair
continent String?
last location - continent
getter/setter pair
continentCode String?
last location - continent code
getter/setter pair
country String?
last location - country
getter/setter pair
countryCode String?
last location - country code
getter/setter pair
courseCompletions int?
Total courses completed
getter/setter pair
dateJoined String
Registration Timestamp e.g 2022-05-05T00:00:00+00:00
getter/setter pair
email String
learner email
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
lastActivity String
Last Activity Timestamp e.g 2022-05-05T00:00:00+00:00
getter/setter pair
location String?
last location
getter/setter pair
name String
learner Name
getter/setter pair
operatingSystem String?
last known operating system
getter/setter pair
region String?
last location - region
getter/setter pair
regionCode String?
last location - region code
getter/setter pair
resolution String?
last known browser resolution
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeSpentOvertime Map<String, Object>
getter/setter pair
totalAssessments int?
Total assessments attempted
getter/setter pair
totalTimeSpent int?
Total time spent in seconds
getter/setter pair
totalVideos int?
Total videos watched
getter/setter pair
username String
learner username
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) LearnerInformationAPIData?
Returns a new LearnerInformationAPIData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<LearnerInformationAPIData>
mapFromJson(dynamic json) Map<String, LearnerInformationAPIData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<LearnerInformationAPIData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.