toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() => 'LearnerInformationAPIData[username=$username, name=$name, email=$email, dateJoined=$dateJoined, lastActivity=$lastActivity, totalAssessments=$totalAssessments, totalTimeSpent=$totalTimeSpent, totalVideos=$totalVideos, courseCompletions=$courseCompletions, timeSpentOvertime=$timeSpentOvertime, continent=$continent, continentCode=$continentCode, country=$country, countryCode=$countryCode, region=$region, regionCode=$regionCode, location=$location, city=$city, browser=$browser, operatingSystem=$operatingSystem, resolution=$resolution]';