MentorFromTemplateWithSettingRequest class

Constructors

MentorFromTemplateWithSettingRequest({required String templateName, required String displayName, required String description, required String profileImage, required String initialMessage, required String suggestedMessage, required String theme, required String userMessageColor, required String mentorBubbleColor, required String alignMentorBubble, String? systemPrompt, String? llmName, String? mentorVisibility, bool? enableImageGeneration})
Returns a new MentorFromTemplateWithSettingRequest instance.

Properties

alignMentorBubble String
getter/setter pair
description String
getter/setter pair
displayName String
getter/setter pair
enableImageGeneration bool?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
initialMessage String
getter/setter pair
llmName String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
mentorBubbleColor String
getter/setter pair
mentorVisibility String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
profileImage String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestedMessage String
getter/setter pair
systemPrompt String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
templateName String
getter/setter pair
theme String
getter/setter pair
userMessageColor String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) MentorFromTemplateWithSettingRequest?
Returns a new MentorFromTemplateWithSettingRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<MentorFromTemplateWithSettingRequest>
mapFromJson(dynamic json) Map<String, MentorFromTemplateWithSettingRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<MentorFromTemplateWithSettingRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.