MentorSettings class

Constructors

MentorSettings({required int id, required String mentor, required String metadata, required String allowAnonymous, required String mentorDescription, String? displayName, String? profileImage, String? initialMessage, String? suggestedMessage, ThemeEnum? theme, String? userMessageColor, String? mentorBubbleColor, AlignMentorBubbleEnum? alignMentorBubble, MentorSettingsMentorVisibility? mentorVisibility, bool? enableImageGeneration, String? customCss})
Returns a new MentorSettings instance.

Properties

alignMentorBubble AlignMentorBubbleEnum?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
allowAnonymous String
getter/setter pair
customCss String?
getter/setter pair
displayName String?
getter/setter pair
enableImageGeneration bool?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id int
getter/setter pair
initialMessage String?
getter/setter pair
mentor String
getter/setter pair
mentorBubbleColor String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
mentorDescription String
getter/setter pair
mentorVisibility MentorSettingsMentorVisibility?
getter/setter pair
metadata String
getter/setter pair
profileImage String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestedMessage String?
getter/setter pair
theme ThemeEnum?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
userMessageColor String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) MentorSettings?
Returns a new MentorSettings instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<MentorSettings>
mapFromJson(dynamic json) Map<String, MentorSettings>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<MentorSettings>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.