Order class

Constructors

Order({required int customerId, required String status, required DateTime orderDate, required String coupons, required String value})
Returns a new Order instance.

Properties

coupons String
Total discount by coupons
getter/setter pair
customerId int
WP Customer ID
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
orderDate DateTime
WooCommerce order date
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
WooCommerce order status
getter/setter pair
value String
Net order value
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Order?
Returns a new Order instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Order>
mapFromJson(dynamic json) Map<String, Order>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Order>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.