overviewOrgsActiveUsersRetrieve method
Count of users with known activity within the past 30 days on a per day basis Query Params 1. start_date e.g 2020-10-01 2. end_date e.g 2020-10-10 Default result when no query param is added is last_7_days (today inclusive) Returns ``` { "data": { "2022-04-26": 0, "2022-04-27": 0, "2022-04-28": 0, "2022-04-29": 60, ... "2022-05-05": 0 }, "total": 60, "meta": { "change_last_seven_days": 0, "change_last_seven_days_percent": 0.0, "change_last_thirty_days": 0, "change_last_thirty_days_percent": 0.0, "change_range": 0, "change_range_percent": 0.0, "total": 0, } }
Parameters:
Implementation
Future<OvertimeWithChangeInfo?> overviewOrgsActiveUsersRetrieve(String org, { String? endDate, String? format, int? groupId, String? startDate, }) async {
final response = await overviewOrgsActiveUsersRetrieveWithHttpInfo(org, endDate: endDate, format: format, groupId: groupId, startDate: startDate, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'OvertimeWithChangeInfo',) as OvertimeWithChangeInfo;
}
return null;
}