Pagination class

Constructors

Pagination({required int totalItems, required int currentPage, required int perPage, required int totalPages})
Returns a new Pagination instance.

Properties

currentPage int
Current Page
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
perPage int
Size of data returned per page
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalItems int
Total records
getter/setter pair
totalPages int
Amount of pages
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Pagination?
Returns a new Pagination instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Pagination>
mapFromJson(dynamic json) Map<String, Pagination>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Pagination>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.