PatchedStudentAnswer class

Constructors

PatchedStudentAnswer({int? id, MathStudent? mathStudent, MathQuestionWithAnswer? question, String? answer, String? image, bool? isCorrect, int? score, String? feedback, DateTime? createdAt, DateTime? updatedAt})
Returns a new PatchedStudentAnswer instance.

Properties

answer String?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
createdAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
feedback String?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id int?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
image String?
getter/setter pair
isCorrect bool?
getter/setter pair
mathStudent MathStudent?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
question MathQuestionWithAnswer?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int?
Minimum value: 0 Maximum value: 2147483647
getter/setter pair
updatedAt DateTime?
Please note: This property should have been non-nullable! Since the specification file does not include a default value (using the "default:" property), however, the generated source code must fall back to having a nullable type. Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) PatchedStudentAnswer?
Returns a new PatchedStudentAnswer instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<PatchedStudentAnswer>
mapFromJson(dynamic json) Map<String, PatchedStudentAnswer>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<PatchedStudentAnswer>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.