performanceOrgsCoursesGradingDetailRetrieve method

Future<CourseGradingDetail?> performanceOrgsCoursesGradingDetailRetrieve(
  1. String courseId,
  2. String org, {
  3. String? format,
  4. int? groupId,
})

Grading summary for the entire course overview in a tree-like format Kwargs course_id

Parameters:

  • String courseId (required):

  • String org (required):

  • String format: Format * json - json

  • int groupId: Cohort Group ID

Implementation

Future<CourseGradingDetail?> performanceOrgsCoursesGradingDetailRetrieve(String courseId, String org, { String? format, int? groupId, }) async {
  final response = await performanceOrgsCoursesGradingDetailRetrieveWithHttpInfo(courseId, org,  format: format, groupId: groupId, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'CourseGradingDetail',) as CourseGradingDetail;

  }
  return null;
}