performanceOrgsCoursesGradingPerLearnerRetrieve method
Grading information per enrolled user in a course Kwargs course_id
Parameters:
Implementation
Future<GradingPerUser?> performanceOrgsCoursesGradingPerLearnerRetrieve(String courseId, String org, { String? format, int? groupId, }) async {
final response = await performanceOrgsCoursesGradingPerLearnerRetrieveWithHttpInfo(courseId, org, format: format, groupId: groupId, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'GradingPerUser',) as GradingPerUser;
}
return null;
}