performanceOrgsCoursesGradingSummaryRetrieve method

Future<CourseGradeSummary?> performanceOrgsCoursesGradingSummaryRetrieve(
  1. String courseId,
  2. String org, {
  3. String? format,
  4. int? groupId,
})

Returns average grades across various assignment types in a course Query Params course_id Returns: dict { "data": { \"assignment_type': <str>, \"weight\": <float>, \"average_weighted_grade\": <float>, \"average_section_grade\": <float> }, ... }

Parameters:

  • String courseId (required):

  • String org (required):

  • String format: Format * json - json

  • int groupId: Cohort Group ID

Implementation

Future<CourseGradeSummary?> performanceOrgsCoursesGradingSummaryRetrieve(String courseId, String org, { String? format, int? groupId, }) async {
  final response = await performanceOrgsCoursesGradingSummaryRetrieveWithHttpInfo(courseId, org,  format: format, groupId: groupId, );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'CourseGradeSummary',) as CourseGradeSummary;

  }
  return null;
}