perlearnerOrgsUsersCoursesOverviewEngagementIndexRetrieveWithHttpInfo method
Average of days with atleast an activity within ENGAGEMENT_INDEX_PERIOD consecutive days for a learner in a course
Note: This method returns the HTTP Response.
Parameters:
Implementation
Future<Response> perlearnerOrgsUsersCoursesOverviewEngagementIndexRetrieveWithHttpInfo(String courseId, String org, String userId,) async {
// ignore: prefer_const_declarations
final path = r'/api/perlearner/orgs/{org}/users/{user_id}/courses/{course_id}/overview/engagement-index'
.replaceAll('{course_id}', courseId)
.replaceAll('{org}', org)
.replaceAll('{user_id}', userId);
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}