perlearnerOrgsUsersCoursesVideosRetrieve method
List of videos within a course a learner has watched Kwargs 1. course_id e.g course-v1:Org+Course4+Run 2. user_id e.g developer@ibleducation.com or dev123 (username|email) Default result when no query param is added is [], 0
Parameters:
Implementation
Future<PerLearnerCourseVideosWatched?> perlearnerOrgsUsersCoursesVideosRetrieve(String courseId, String org, String userId, { String? format, int? groupId, }) async {
final response = await perlearnerOrgsUsersCoursesVideosRetrieveWithHttpInfo(courseId, org, userId, format: format, groupId: groupId, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'PerLearnerCourseVideosWatched',) as PerLearnerCourseVideosWatched;
}
return null;
}