perlearnerOrgsUsersGradesPerCourseRetrieve method
Summary Grading Information for a learner on a per-enrollment basis Query Params 1. user_id e.g developer@ibleducation.com or dev123 (username|email)
Parameters:
Implementation
Future<PerlearnerGradingPerCourseAPI?> perlearnerOrgsUsersGradesPerCourseRetrieve(String org, String userId, { String? format, int? groupId, }) async {
final response = await perlearnerOrgsUsersGradesPerCourseRetrieveWithHttpInfo(org, userId, format: format, groupId: groupId, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'PerlearnerGradingPerCourseAPI',) as PerlearnerGradingPerCourseAPI;
}
return null;
}