perlearnerOrgsUsersRetrieve method
List of entire learners on the platform with aggregated enrollments, completions and time spent
Parameters:
Implementation
Future<PerlearnerUserList?> perlearnerOrgsUsersRetrieve(String org, { String? format, int? groupId, int? length, int? page, String? search, }) async {
final response = await perlearnerOrgsUsersRetrieveWithHttpInfo(org, format: format, groupId: groupId, length: length, page: page, search: search, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'PerlearnerUserList',) as PerlearnerUserList;
}
return null;
}