perlearnerOrgsUsersVideosPerCourseRetrieve method
Summary Videos watched data for a learner per enrollment Query Params 1. user_id e.g developer@ibleducation.com or dev123 (username|email)
Parameters:
Implementation
Future<PerlearnerEngagementVideosWatchedPerCourse?> perlearnerOrgsUsersVideosPerCourseRetrieve(String org, String userId, { String? endDate, String? format, int? groupId, String? startDate, }) async {
final response = await perlearnerOrgsUsersVideosPerCourseRetrieveWithHttpInfo(org, userId, endDate: endDate, format: format, groupId: groupId, startDate: startDate, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'PerlearnerEngagementVideosWatchedPerCourse',) as PerlearnerEngagementVideosWatchedPerCourse;
}
return null;
}