PointsPercentile class

Constructors

PointsPercentile({required String username, required double points, required double percentile})
Returns a new PointsPercentile instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
percentile double
Percentile of points for user. If an org was provided, this is the percentile of the user relative to users within the org.
getter/setter pair
points double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) PointsPercentile?
Returns a new PointsPercentile instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<PointsPercentile>
mapFromJson(dynamic json) Map<String, PointsPercentile>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<PointsPercentile>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.