recommendationsOrgsUsersRetrieve method

Future<RecommendationSearchAPI?> recommendationsOrgsUsersRetrieve(
  1. String org,
  2. String userId
)

API endpoint that returns a search api url prepopulated with context data See http://localhost:8000/api/schema/swagger-ui/#/recommendations

Parameters:

Implementation

Future<RecommendationSearchAPI?> recommendationsOrgsUsersRetrieve(String org, String userId,) async {
  final response = await recommendationsOrgsUsersRetrieveWithHttpInfo(org, userId,);
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'RecommendationSearchAPI',) as RecommendationSearchAPI;

  }
  return null;
}