ReportRequest class

Constructors

ReportRequest({required String reportName, required String owner})
Returns a new ReportRequest instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
owner String
Report Owner
getter/setter pair
reportName String
Report slug, this is passed when calling the create report endpoint
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) ReportRequest?
Returns a new ReportRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<ReportRequest>
mapFromJson(dynamic json) Map<String, ReportRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<ReportRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.