ReportsApi class

Constructors

ReportsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportsOrgsList(String org) Future<List<ReportList>?>
Returns list of report available in the system to download. extra_query_params defines additional query params that can be passed to the report create body If the report has been previously requested, it returns the status of the report
reportsOrgsListWithHttpInfo(String org) Future<Response>
Returns list of report available in the system to download. extra_query_params defines additional query params that can be passed to the report create body If the report has been previously requested, it returns the status of the report
reportsOrgsNewCreate(String org, ReportRequest reportRequest) Future<ReportCreate?>
Triggers a new report generation. If the report has been previously requested, it returns the status of the report The current duration for generated report {settings.REPORT_EXPIRY_SECONDS/3600} hours. Given a sample result of the api call json [ { \"data\": [ { \"display_name\": \"User Report 1\", \"description\": \"A short Description of Report 1\", \"report_name\": \"report-1\", \"icon\": \"http://some-icon.png\", \"extra_query_params\": [ \"course_id\", \"learner_id\" ], \"status\": {} } ] } ] The body of the request would be json { \"report_name\": \"report-1\", \"owner\": \"owner-name\" \"learner_id\": \"learner-id\", \"course_id\": \"course-id\", }
reportsOrgsNewCreateWithHttpInfo(String org, ReportRequest reportRequest) Future<Response>
Triggers a new report generation. If the report has been previously requested, it returns the status of the report The current duration for generated report {settings.REPORT_EXPIRY_SECONDS/3600} hours. Given a sample result of the api call json [ { \"data\": [ { \"display_name\": \"User Report 1\", \"description\": \"A short Description of Report 1\", \"report_name\": \"report-1\", \"icon\": \"http://some-icon.png\", \"extra_query_params\": [ \"course_id\", \"learner_id\" ], \"status\": {} } ] } ] The body of the request would be json { \"report_name\": \"report-1\", \"owner\": \"owner-name\" \"learner_id\": \"learner-id\", \"course_id\": \"course-id\", }
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited