RetrieverDocumentEmbeddingRequest class

Constructors

RetrieverDocumentEmbeddingRequest({required String pathway, String? documentName, String? documentType, String? url, bool? train})
Returns a new RetrieverDocumentEmbeddingRequest instance.

Properties

documentName String?
The name of the document
getter/setter pair
documentType String?
The type of the document
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
pathway String
The pathway to retrain the document in
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
train bool?
The type of the document
getter/setter pair
url String?
The url of the document
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) RetrieverDocumentEmbeddingRequest?
Returns a new RetrieverDocumentEmbeddingRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<RetrieverDocumentEmbeddingRequest>
mapFromJson(dynamic json) Map<String, RetrieverDocumentEmbeddingRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<RetrieverDocumentEmbeddingRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.