RolesApi class

Constructors

RolesApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rolesPlatformOrgsRolesUsersDesiredRolesRetrieve(String org, String username) Future<DesiredRole?>
Parameters:
rolesPlatformOrgsRolesUsersDesiredRolesRetrieveWithHttpInfo(String org, String username) Future<Response>
Performs an HTTP 'GET /api/roles/platform/orgs/{org}/roles/users/{username}/desired-roles/' operation and returns the Response. Parameters:
rolesPlatformOrgsRolesUsersReportedRolesRetrieve(String org, String username) Future<ReportedRole?>
Parameters:
rolesPlatformOrgsRolesUsersReportedRolesRetrieveWithHttpInfo(String org, String username) Future<Response>
Performs an HTTP 'GET /api/roles/platform/orgs/{org}/roles/users/{username}/reported-roles/' operation and returns the Response. Parameters:
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited