SaasApi class

Constructors

SaasApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saasAwsSubscriptionExpiryWebhookCreate() Future<void>
Update subscription expiry date
saasAwsSubscriptionExpiryWebhookCreateWithHttpInfo() Future<Response>
Update subscription expiry date
saasCreateStripeCustomerCreate() Future<void>
Stripe customer portal
saasCreateStripeCustomerCreateWithHttpInfo() Future<Response>
Stripe customer portal
saasCreateStripeCustomerPortalCreate() Future<void>
saasCreateStripeCustomerPortalCreateWithHttpInfo() Future<Response>
Performs an HTTP 'POST /api/saas/create/stripe/customer/portal/' operation and returns the Response.
saasCreateSubscriptionRetrieve() Future<void>
Stripe product payment intent initiation class
saasCreateSubscriptionRetrieveWithHttpInfo() Future<Response>
Stripe product payment intent initiation class
saasCustomerPortalWebhookRetrieve() Future<void>
Create a customer portal
saasCustomerPortalWebhookRetrieveWithHttpInfo() Future<Response>
Create a customer portal
saasLaunchTenantCreate() Future<void>
User/tenant creation flow
saasLaunchTenantCreateWithHttpInfo() Future<Response>
User/tenant creation flow
saasPaymentCancelRetrieve() Future<void>
Stripe cancel webhook
saasPaymentCancelRetrieveWithHttpInfo() Future<Response>
Stripe cancel webhook
saasPaymentSuccessRetrieve() Future<void>
Stripe success webhook
saasPaymentSuccessRetrieveWithHttpInfo() Future<Response>
Stripe success webhook
saasStripeProductPurchaseRetrieve() Future<void>
Stripe product payment intent initiation class
saasStripeProductPurchaseRetrieveWithHttpInfo() Future<Response>
Stripe product payment intent initiation class
saasSubscriptionCancelRetrieve() Future<void>
Stripe cancel webhook
saasSubscriptionCancelRetrieveWithHttpInfo() Future<Response>
Stripe cancel webhook
saasSubscriptionSuccessRetrieve() Future<void>
Stripe success webhook
saasSubscriptionSuccessRetrieveWithHttpInfo() Future<Response>
Stripe success webhook
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited