ServiceApi class

Constructors

ServiceApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serviceLaunchTenantCreate() Future<void>
User/tenant creation flow
serviceLaunchTenantCreateWithHttpInfo() Future<Response>
User/tenant creation flow
serviceManageUserCreate() Future<void>
User creation flow
serviceManageUserCreateWithHttpInfo() Future<Response>
User creation flow
serviceManageUserRoleCreate() Future<void>
Make user tenant admin
serviceManageUserRoleCreateWithHttpInfo() Future<Response>
Make user tenant admin
serviceTenantValidationCreate() Future<void>
Check if tenant exists or not
serviceTenantValidationCreateWithHttpInfo() Future<Response>
Check if tenant exists or not
serviceTokenRetrieve() Future<void>
GET Gets site hash_key from or Gets site_id form hash_key
serviceTokenRetrieveWithHttpInfo() Future<Response>
GET Gets site hash_key from or Gets site_id form hash_key
serviceUserValidationCreate() Future<void>
Check if tenant exists or not
serviceUserValidationCreateWithHttpInfo() Future<Response>
Check if tenant exists or not
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited