SkillDetail class

Constructors

SkillDetail({List<CourseSkill> courses = const [], required int relatedSkills, String? name})
Returns a new SkillDetail instance.

Properties

courses List<CourseSkill>
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String?
Display name
getter/setter pair
relatedSkills int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SkillDetail?
Returns a new SkillDetail instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SkillDetail>
mapFromJson(dynamic json) Map<String, SkillDetail>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SkillDetail>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.