SkillsApi class

Constructors

SkillsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
skillsOrgsSkillsList(String org) Future<List<SkillInfo>?>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsListWithHttpInfo(String org) Future<Response>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsPercentileList(String org) Future<List<PointsPercentile>?>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsPercentileListWithHttpInfo(String org) Future<Response>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsPercentileRetrieve(String org, int skillId) Future<PointsPercentile?>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsPercentileRetrieveWithHttpInfo(String org, int skillId) Future<Response>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsRetrieve(String org, String skillName) Future<SkillDetail?>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsRetrieveWithHttpInfo(String org, String skillName) Future<Response>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsThresholdsCreate(String org, SkillThreshold skillThreshold) Future<SkillThreshold?>
Parameters:
skillsOrgsSkillsThresholdsCreateWithHttpInfo(String org, SkillThreshold skillThreshold) Future<Response>
Performs an HTTP 'POST /api/skills/orgs/{org}/skills/thresholds/' operation and returns the Response. Parameters:
skillsOrgsSkillsThresholdsDestroy(String org) Future<void>
Parameters:
skillsOrgsSkillsThresholdsDestroyWithHttpInfo(String org) Future<Response>
Performs an HTTP 'DELETE /api/skills/orgs/{org}/skills/thresholds/' operation and returns the Response. Parameters:
skillsOrgsSkillsThresholdsPartialUpdate(String org, {PatchedSkillThreshold? patchedSkillThreshold}) Future<SkillThreshold?>
Parameters:
skillsOrgsSkillsThresholdsPartialUpdateWithHttpInfo(String org, {PatchedSkillThreshold? patchedSkillThreshold}) Future<Response>
Performs an HTTP 'PATCH /api/skills/orgs/{org}/skills/thresholds/' operation and returns the Response. Parameters:
skillsOrgsSkillsThresholdsRetrieve(String org) Future<SkillThreshold?>
Parameters:
skillsOrgsSkillsThresholdsRetrieveWithHttpInfo(String org) Future<Response>
Performs an HTTP 'GET /api/skills/orgs/{org}/skills/thresholds/' operation and returns the Response. Parameters:
skillsOrgsSkillsUsersDesiredSkillsRetrieve(String org, String userId) Future<DesiredSkill?>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsUsersDesiredSkillsRetrieveWithHttpInfo(String org, String userId) Future<Response>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsUsersPointPercentileRetrieve(String org, String userId) Future<UserSkillPointsPercentile?>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsUsersPointPercentileRetrieveWithHttpInfo(String org, String userId) Future<Response>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsUsersReportedSkillsRetrieve(String org, String userId) Future<ReportedSkill?>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsUsersReportedSkillsRetrieveWithHttpInfo(String org, String userId) Future<Response>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsUsersRetrieve(String org, String userId) Future<UserSkill?>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
skillsOrgsSkillsUsersRetrieveWithHttpInfo(String org, String userId) Future<Response>
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited