TimeChildData class

Constructors

TimeChildData({required String displayName, required String id, List<SubTimeChild> children = const [], String? blockId, int? totalTime})
Returns a new TimeChildData instance.

Properties

blockId String?
block id
getter/setter pair
children List<SubTimeChild>
getter/setter pair
displayName String
Display name
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
block id
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTime int?
Total time spent
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) TimeChildData?
Returns a new TimeChildData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<TimeChildData>
mapFromJson(dynamic json) Map<String, TimeChildData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<TimeChildData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.