TimeSpentByUsersInCourseData class
Constructors
- TimeSpentByUsersInCourseData({required String username, required String fullName, required String email, required int assessments, required String timeSpent})
- Returns a new TimeSpentByUsersInCourseData instance.
Properties
- assessments ↔ int
-
Total assessments
getter/setter pair
- email ↔ String
-
learner email
getter/setter pair
- fullName ↔ String
-
learner Name
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeSpent ↔ String
-
Time spent formatted in seconds
getter/setter pair
- username ↔ String
-
learner username
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → TimeSpentByUsersInCourseData? -
Returns a new TimeSpentByUsersInCourseData instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< TimeSpentByUsersInCourseData> -
mapFromJson(
dynamic json) → Map< String, TimeSpentByUsersInCourseData> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< TimeSpentByUsersInCourseData> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.