TrainDocumentViewRequest class

Constructors

TrainDocumentViewRequest({required String pathway, required String type, String? url, String? file})
Returns a new TrainDocumentViewRequest instance.

Properties

file String?
File to be trained
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
pathway String
Pathway for document to be trained in
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Type of document e.g file
getter/setter pair
url String?
Url of the document to be trained
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) TrainDocumentViewRequest?
Returns a new TrainDocumentViewRequest instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<TrainDocumentViewRequest>
mapFromJson(dynamic json) Map<String, TrainDocumentViewRequest>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<TrainDocumentViewRequest>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.