UserSkill class

Constructors

UserSkill({required Skill skill, List<CoursePoint> courses = const [], List<ResourcePoint> resources = const [], required int totalPoints, double? percentile})
Returns a new UserSkill instance.

Properties

courses List<CoursePoint>
Courses with skill and associated points
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
percentile double?
Percentile of points for user.
getter/setter pair
resources List<ResourcePoint>
Resources with skill and associated points
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skill Skill
getter/setter pair
totalPoints int
Total points for skill
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) UserSkill?
Returns a new UserSkill instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<UserSkill>
mapFromJson(dynamic json) Map<String, UserSkill>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<UserSkill>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.