UserSkillPointsPercentile class

Constructors

UserSkillPointsPercentile({required String username, required double totalPoints, required double percentile})
Returns a new UserSkillPointsPercentile instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
percentile double
Percentile of points for user. If an org was provided, this is the percentile of the user relative to users within the org.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalPoints double
getter/setter pair
username String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) UserSkillPointsPercentile?
Returns a new UserSkillPointsPercentile instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<UserSkillPointsPercentile>
mapFromJson(dynamic json) Map<String, UserSkillPointsPercentile>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<UserSkillPointsPercentile>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.