percentile property

double percentile
getter/setter pair

Percentile of points for user. If an org was provided, this is the percentile of the user relative to users within the org.

Implementation

double percentile;