VideoBlock class
Constructors
- VideoBlock({required String displayName, required String id, int? totalUsers})
- Returns a new VideoBlock instance.
Properties
- displayName ↔ String
-
Video name
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String
-
Video Id
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalUsers ↔ int?
-
Total users who have watched the video
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → VideoBlock? -
Returns a new VideoBlock instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< VideoBlock> -
mapFromJson(
dynamic json) → Map< String, VideoBlock> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< VideoBlock> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.