VideoEngagementPerCourseData class

Constructors

VideoEngagementPerCourseData({required String name, required String courseId, required int numVids, required int numWatched, required int timeWatched, required double avgPercentWatched, required double avgTimeWatched})
Returns a new VideoEngagementPerCourseData instance.

Properties

avgPercentWatched double
Average percentage of videos watched per user per course
getter/setter pair
avgTimeWatched double
Average time spent per learner
getter/setter pair
courseId String
edx Course Id
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
Course name
getter/setter pair
numVids int
Number of videos in course
getter/setter pair
numWatched int
Number of videos watched
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeWatched int
Total time spent by all users watching videos
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) VideoEngagementPerCourseData?
Returns a new VideoEngagementPerCourseData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<VideoEngagementPerCourseData>
mapFromJson(dynamic json) Map<String, VideoEngagementPerCourseData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<VideoEngagementPerCourseData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.