VideosSpecificCourseData class

Constructors

VideosSpecificCourseData({required String displayName, required String id, required int duration, required int totalTime, required int totalUsers, required double averageTime})
Returns a new VideosSpecificCourseData instance.

Properties

averageTime double
Average time spent per learner
getter/setter pair
displayName String
Course name
getter/setter pair
duration int
Video duration
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String
Video Id
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTime int
Total time spent by users watching
getter/setter pair
totalUsers int
Total users who have watched this video
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) VideosSpecificCourseData?
Returns a new VideosSpecificCourseData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<VideosSpecificCourseData>
mapFromJson(dynamic json) Map<String, VideosSpecificCourseData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<VideosSpecificCourseData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.