WatchedVideosPerCourseData class

Constructors

WatchedVideosPerCourseData({required String courseId, required String name, required int count, required double percentage})
Returns a new WatchedVideosPerCourseData instance.

Properties

count int
Number of watched videos
getter/setter pair
courseId String
Edx Course ID
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
name String
Course Name
getter/setter pair
percentage double
Percentage ...
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) WatchedVideosPerCourseData?
Returns a new WatchedVideosPerCourseData instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<WatchedVideosPerCourseData>
mapFromJson(dynamic json) Map<String, WatchedVideosPerCourseData>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<WatchedVideosPerCourseData>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.