ActivityData class
Constructors
- ActivityData({required String courseId, required String name, required String courseStart, required String courseEnd, required double averageTimeInvested, required int timeInvested, required int daysAway, required String lastAccessDate, required int daysAccessed})
- Returns a new ActivityData instance.
Properties
- averageTimeInvested ↔ double
-
Overall course average time invested (other students inclusive)
getter/setter pair
- courseEnd ↔ String
-
Course end date
getter/setter pair
- courseId ↔ String
-
edx Course Id
getter/setter pair
- courseStart ↔ String
-
Course start date
getter/setter pair
- daysAccessed ↔ int
-
Unique days course was accessed
getter/setter pair
- daysAway ↔ int
-
Days from today the course has been accessed
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastAccessDate ↔ String
-
When course was last accessed
getter/setter pair
- name ↔ String
-
Course name
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeInvested ↔ int
-
Total time spent
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ActivityData? -
Returns a new ActivityData instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< ActivityData> -
mapFromJson(
dynamic json) → Map< String, ActivityData> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< ActivityData> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.