AiApi class
Methods
aiAccountOrgsCredentialCreate (String org , LLMCredential lLMCredential )
→ Future <LLMCredential ? >
API View to manage LLM credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsCredentialCreateWithHttpInfo (String org , LLMCredential lLMCredential )
→ Future <Response >
API View to manage LLM credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsCredentialPartialUpdate (String org , {PatchedLLMCredential ? patchedLLMCredential })
→ Future <LLMCredential ? >
API View to manage LLM credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsCredentialPartialUpdateWithHttpInfo (String org , {PatchedLLMCredential ? patchedLLMCredential })
→ Future <Response >
API View to manage LLM credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsCredentialRetrieve (String org )
→ Future <LLMCredential ? >
API View to manage LLM credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsCredentialRetrieveWithHttpInfo (String org )
→ Future <Response >
API View to manage LLM credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsIntegrationCredentialCreate (String org , IntegrationCredential integrationCredential )
→ Future <IntegrationCredential ? >
API View to manage Integration credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsIntegrationCredentialCreateWithHttpInfo (String org , IntegrationCredential integrationCredential )
→ Future <Response >
API View to manage Integration credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsIntegrationCredentialPartialUpdate (String org , {PatchedIntegrationCredential ? patchedIntegrationCredential })
→ Future <IntegrationCredential ? >
API View to manage Integration credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsIntegrationCredentialPartialUpdateWithHttpInfo (String org , {PatchedIntegrationCredential ? patchedIntegrationCredential })
→ Future <Response >
API View to manage Integration credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsIntegrationCredentialRetrieve (String org )
→ Future <IntegrationCredential ? >
API View to manage Integration credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsIntegrationCredentialRetrieveWithHttpInfo (String org )
→ Future <Response >
API View to manage Integration credentials. Sample for value field : {\"key\": \"sk-31343432432434324324324324\"}
aiAccountOrgsPlatformMetadataCreate (String org , {IBLAIPlatformMeta ? iBLAIPlatformMeta })
→ Future <IBLAIPlatformMeta ? >
In order to use google as your LLM provider, you need to specify google_project (your google cloud project id) and google_location, which defaults to us-central1
aiAccountOrgsPlatformMetadataCreateWithHttpInfo (String org , {IBLAIPlatformMeta ? iBLAIPlatformMeta })
→ Future <Response >
In order to use google as your LLM provider, you need to specify google_project (your google cloud project id) and google_location, which defaults to us-central1
aiAccountOrgsPlatformMetadataRetrieve (String org )
→ Future <IBLAIPlatformMeta ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiAccountOrgsPlatformMetadataRetrieveWithHttpInfo (String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiAccountOrgsPlatformMetadataUpdate (String org , {IBLAIPlatformMeta ? iBLAIPlatformMeta })
→ Future <IBLAIPlatformMeta ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiAccountOrgsPlatformMetadataUpdateWithHttpInfo (String org , {IBLAIPlatformMeta ? iBLAIPlatformMeta })
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiAccountOrgsTokensList (String org )
→ Future <List <APITokenCost > ? >
Token count
aiAccountOrgsTokensListWithHttpInfo (String org )
→ Future <Response >
Token count
aiBotV1BotsBotCommandsCreate (String org , BotCommand botCommand )
→ Future <BotCommand ? >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsCreateWithHttpInfo (String org , BotCommand botCommand )
→ Future <Response >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsDestroy (int id , String org )
→ Future <void >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsDestroyWithHttpInfo (int id , String org )
→ Future <Response >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsList (String org )
→ Future <List <BotCommand > ? >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsListWithHttpInfo (String org )
→ Future <Response >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsPartialUpdate (int id , String org , {PatchedBotCommand ? patchedBotCommand })
→ Future <BotCommand ? >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsPartialUpdateWithHttpInfo (int id , String org , {PatchedBotCommand ? patchedBotCommand })
→ Future <Response >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsRetrieve (int id , String org )
→ Future <BotCommand ? >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsRetrieveWithHttpInfo (int id , String org )
→ Future <Response >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsUpdate (int id , String org , BotCommand botCommand )
→ Future <BotCommand ? >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCommandsUpdateWithHttpInfo (int id , String org , BotCommand botCommand )
→ Future <Response >
Create slash commands for a specific bot eg. /iblai-baseline
aiBotV1BotsBotCreate (String org , BotCreate botCreate )
→ Future <BotCreate ? >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotCreateWithHttpInfo (String org , BotCreate botCreate )
→ Future <Response >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotDestroy (int id , String org )
→ Future <void >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotDestroyWithHttpInfo (int id , String org )
→ Future <Response >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotList (String org )
→ Future <List <Bot > ? >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotListWithHttpInfo (String org )
→ Future <Response >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotPartialUpdate (int id , String org , {PatchedBotCreate ? patchedBotCreate })
→ Future <BotCreate ? >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotPartialUpdateWithHttpInfo (int id , String org , {PatchedBotCreate ? patchedBotCreate })
→ Future <Response >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotRetrieve (int id , String org )
→ Future <Bot ? >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotRetrieveWithHttpInfo (int id , String org )
→ Future <Response >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotUpdate (int id , String org , BotCreate botCreate )
→ Future <BotCreate ? >
Create modify and update bot information for a specific tenant.
aiBotV1BotsBotUpdateWithHttpInfo (int id , String org , BotCreate botCreate )
→ Future <Response >
Create modify and update bot information for a specific tenant.
aiBotV1BotsWebhooksDiscordCreate (String org , DiscordWebhook discordWebhook )
→ Future <DiscordWebhook ? >
Webhook endpoint to receive and process discord messages.
aiBotV1BotsWebhooksDiscordCreateWithHttpInfo (String org , DiscordWebhook discordWebhook )
→ Future <Response >
Webhook endpoint to receive and process discord messages.
aiBotV1BotsWebhooksSlackCreate (String org , SlackWebhook slackWebhook )
→ Future <SlackWebhook ? >
Parameters:
aiBotV1BotsWebhooksSlackCreateWithHttpInfo (String org , SlackWebhook slackWebhook )
→ Future <Response >
Performs an HTTP 'POST /api/ai/bot/v1/bots/webhooks/{org}/slack/' operation and returns the Response.
Parameters:
aiBotV1BotsWebhooksWebexCreate (String org , WebexWebhook webexWebhook )
→ Future <WebexWebhook ? >
Webhook endpoint to receive and process discord messages.
aiBotV1BotsWebhooksWebexCreateWithHttpInfo (String org , WebexWebhook webexWebhook )
→ Future <Response >
Webhook endpoint to receive and process discord messages.
aiBotV1BotsWebhooksWhatsappCreate (String org , WhatAppWebHook whatAppWebHook )
→ Future <WhatAppWebHook ? >
Webhook endpoint to receive and process whatsapp messages.
aiBotV1BotsWebhooksWhatsappCreateWithHttpInfo (String org , WhatAppWebHook whatAppWebHook )
→ Future <Response >
Webhook endpoint to receive and process whatsapp messages.
aiBotV1BotsWebhooksWhatsappRetrieve (String org )
→ Future <WhatAppWebHook ? >
Respond to whatsapp's webhook challenge.
aiBotV1BotsWebhooksWhatsappRetrieveWithHttpInfo (String org )
→ Future <Response >
Respond to whatsapp's webhook challenge.
aiIndexOrgsUsersDocumentsRetrieverDocumentsRetrieve (String documentId , String org , String userId )
→ Future <RetrieverDocumentEmbedding ? >
Get document resource details for a tenant
aiIndexOrgsUsersDocumentsRetrieverDocumentsRetrieveWithHttpInfo (String documentId , String org , String userId )
→ Future <Response >
Get document resource details for a tenant
aiIndexOrgsUsersDocumentsRetrieverDocumentsUpdate (String documentId , String org , String userId , RetrieverDocumentEmbeddingRequest retrieverDocumentEmbeddingRequest )
→ Future <RetrieverDocumentEmbedding ? >
Update document resource details for a tenant
aiIndexOrgsUsersDocumentsRetrieverDocumentsUpdateWithHttpInfo (String documentId , String org , String userId , RetrieverDocumentEmbeddingRequest retrieverDocumentEmbeddingRequest )
→ Future <Response >
Update document resource details for a tenant
aiIndexOrgsUsersMultilingualRetrieverTrainCreate (String org , String userId , RetreiverTrainViewRequest retreiverTrainViewRequest )
→ Future <RetreiverTrainViewResponse ? >
Train document from other languages to english
aiIndexOrgsUsersMultilingualRetrieverTrainCreateWithHttpInfo (String org , String userId , RetreiverTrainViewRequest retreiverTrainViewRequest )
→ Future <Response >
Train document from other languages to english
aiIndexOrgsUsersPathwaysRetrieverDocumentsRetrieve (String org , String pathway , String userId )
→ Future <RetrieverDocumentEmbedding ? >
Get document resources for a tenant
aiIndexOrgsUsersPathwaysRetrieverDocumentsRetrieveWithHttpInfo (String org , String pathway , String userId )
→ Future <Response >
Get document resources for a tenant
aiIndexOrgsUsersRetrieverSearchCreate (String org , String userId , RetrieverRequestSearch retrieverRequestSearch )
→ Future <RetrieverResponseSearch ? >
Retrieve similar documents to the query
aiIndexOrgsUsersRetrieverSearchCreateWithHttpInfo (String org , String userId , RetrieverRequestSearch retrieverRequestSearch )
→ Future <Response >
Retrieve similar documents to the query
aiIndexOrgsUsersRetrieverTrainCreate (String org , String userId , RetreiverTrainViewRequest retreiverTrainViewRequest )
→ Future <RetreiverTrainViewResponse ? >
Train documents
aiIndexOrgsUsersRetrieverTrainCreateWithHttpInfo (String org , String userId , RetreiverTrainViewRequest retreiverTrainViewRequest )
→ Future <Response >
Train documents
Retrieve similar documents sources to the query
Retrieve similar documents sources to the query
aiIndexOrgsUsersTasksRetrieve (String org , String taskId , String userId )
→ Future <CheckDocumentTrainingStatus ? >
Check document status of training
aiIndexOrgsUsersTasksRetrieveWithHttpInfo (String org , String taskId , String userId )
→ Future <Response >
Check document status of training
aiIndexOrgsUsersTrainDocumentCreate (String org , String userId , TrainDocumentViewRequest trainDocumentViewRequest )
→ Future <TrainDocumentViewResponse ? >
Train documents
aiIndexOrgsUsersTrainDocumentCreateWithHttpInfo (String org , String userId , TrainDocumentViewRequest trainDocumentViewRequest )
→ Future <Response >
Train documents
aiIndexOrgsUsersTrainSessionDocumentSessionsCreate (String org , String sessionId , String userId )
→ Future <TrainChatSessionDocumentView ? >
Train in chat session documents
aiIndexOrgsUsersTrainSessionDocumentSessionsCreateWithHttpInfo (String org , String sessionId , String userId )
→ Future <Response >
Train in chat session documents
aiMathMathMathStudentsCreate (String org , {MathStudent ? mathStudent })
→ Future <MathStudent ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsCreateWithHttpInfo (String org , {MathStudent ? mathStudent })
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsDestroy (int id , String org )
→ Future <void >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsDestroyWithHttpInfo (int id , String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsList (String org )
→ Future <List <MathStudent > ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsListWithHttpInfo (String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsPartialUpdate (int id , String org , {PatchedMathStudent ? patchedMathStudent })
→ Future <MathStudent ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsPartialUpdateWithHttpInfo (int id , String org , {PatchedMathStudent ? patchedMathStudent })
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsRetrieve (int id , String org )
→ Future <MathStudent ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsRetrieveWithHttpInfo (int id , String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsUpdate (int id , String org , {MathStudent ? mathStudent })
→ Future <MathStudent ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathMathStudentsUpdateWithHttpInfo (int id , String org , {MathStudent ? mathStudent })
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathQuestionsDestroy (int id , String org )
→ Future <void >
Retrieve, update and delete math questions.
aiMathMathQuestionsDestroyWithHttpInfo (int id , String org )
→ Future <Response >
Retrieve, update and delete math questions.
aiMathMathQuestionsList (String org )
→ Future <List <MathQuestion > ? >
Retrieve, update and delete math questions.
aiMathMathQuestionsListWithHttpInfo (String org )
→ Future <Response >
Retrieve, update and delete math questions.
aiMathMathQuestionsPartialUpdate (int id , String org , {PatchedMathQuestion ? patchedMathQuestion })
→ Future <MathQuestion ? >
Retrieve, update and delete math questions.
aiMathMathQuestionsPartialUpdateWithHttpInfo (int id , String org , {PatchedMathQuestion ? patchedMathQuestion })
→ Future <Response >
Retrieve, update and delete math questions.
aiMathMathQuestionsRetrieve (int id , String org )
→ Future <MathQuestion ? >
Retrieve, update and delete math questions.
aiMathMathQuestionsRetrieveWithHttpInfo (int id , String org )
→ Future <Response >
Retrieve, update and delete math questions.
aiMathMathSampleQuestionsCreate (String org , SampleQuestionsDocument sampleQuestionsDocument )
→ Future <SampleQuestionsDocument ? >
Upload documents to provide sample questions of reference to generate more math questions from.
aiMathMathSampleQuestionsCreateWithHttpInfo (String org , SampleQuestionsDocument sampleQuestionsDocument )
→ Future <Response >
Upload documents to provide sample questions of reference to generate more math questions from.
aiMathMathSampleQuestionsDestroy (int id , String org )
→ Future <void >
Upload documents to provide sample questions of reference to generate more math questions from.
aiMathMathSampleQuestionsDestroyWithHttpInfo (int id , String org )
→ Future <Response >
Upload documents to provide sample questions of reference to generate more math questions from.
aiMathMathSampleQuestionsList (String org )
→ Future <List <SampleQuestionsDocument > ? >
Upload documents to provide sample questions of reference to generate more math questions from.
aiMathMathSampleQuestionsListWithHttpInfo (String org )
→ Future <Response >
Upload documents to provide sample questions of reference to generate more math questions from.
aiMathMathSampleQuestionsRetrieve (int id , String org )
→ Future <SampleQuestionsDocument ? >
Upload documents to provide sample questions of reference to generate more math questions from.
aiMathMathSampleQuestionsRetrieveWithHttpInfo (int id , String org )
→ Future <Response >
Upload documents to provide sample questions of reference to generate more math questions from.
aiMathMathSkillsCreate (String org , Skill skill )
→ Future <Skill ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsCreateWithHttpInfo (String org , Skill skill )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsDestroy (int id , String org )
→ Future <void >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsDestroyWithHttpInfo (int id , String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsList (String org )
→ Future <List <Skill > ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsListWithHttpInfo (String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsPartialUpdate (int id , String org , {PatchedSkill ? patchedSkill })
→ Future <Skill ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsPartialUpdateWithHttpInfo (int id , String org , {PatchedSkill ? patchedSkill })
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsRetrieve (int id , String org )
→ Future <Skill ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsRetrieveWithHttpInfo (int id , String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsUpdate (int id , String org , Skill skill )
→ Future <Skill ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathSkillsUpdateWithHttpInfo (int id , String org , Skill skill )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersCreate (String org , StudentAnswer studentAnswer )
→ Future <StudentAnswer ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersCreateWithHttpInfo (String org , StudentAnswer studentAnswer )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersDestroy (int id , String org )
→ Future <void >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersDestroyWithHttpInfo (int id , String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersList (String org )
→ Future <List <StudentAnswer > ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersListWithHttpInfo (String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersPartialUpdate (int id , String org , {PatchedStudentAnswer ? patchedStudentAnswer })
→ Future <StudentAnswer ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersPartialUpdateWithHttpInfo (int id , String org , {PatchedStudentAnswer ? patchedStudentAnswer })
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersRetrieve (int id , String org )
→ Future <StudentAnswer ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersRetrieveWithHttpInfo (int id , String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersUpdate (int id , String org , StudentAnswer studentAnswer )
→ Future <StudentAnswer ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMathMathStudentAnswersUpdateWithHttpInfo (int id , String org , StudentAnswer studentAnswer )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorGenerationsStopGenerationCreate (String generationId )
→ Future <WebSocketStopGenerationView ? >
Stop websocket generation
aiMentorGenerationsStopGenerationCreateWithHttpInfo (String generationId )
→ Future <Response >
Stop websocket generation
aiMentorOrgsFreeUsageCountRetrieve (String org )
→ Future <FreeUsageCount ? >
Retrieve the number of questions left for a tenant
aiMentorOrgsFreeUsageCountRetrieveWithHttpInfo (String org )
→ Future <Response >
Retrieve the number of questions left for a tenant
aiMentorOrgsMentorFeedbackCreateCreate (String org , UserChatFeedback userChatFeedback )
→ Future <UserChatFeedback ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorFeedbackCreateCreateWithHttpInfo (String org , UserChatFeedback userChatFeedback )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorFeedbackRetrieve (int feedbackId , String org )
→ Future <UserChatFeedback ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorFeedbackRetrieveWithHttpInfo (int feedbackId , String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorFeedbackUpdate (int feedbackId , String org , UserChatFeedback userChatFeedback )
→ Future <UserChatFeedback ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorFeedbackUpdateWithHttpInfo (int feedbackId , String org , UserChatFeedback userChatFeedback )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorFromTemplateCreate (String org , MentorFromTemplateRequest mentorFromTemplateRequest )
→ Future <Mentor ? >
View to create a mentor from a template
aiMentorOrgsMentorFromTemplateCreateWithHttpInfo (String org , MentorFromTemplateRequest mentorFromTemplateRequest )
→ Future <Response >
View to create a mentor from a template
aiMentorOrgsMentorLlmsRetrieve (String org )
→ Future <MentorLLMFlowResponse ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorLlmsRetrieveWithHttpInfo (String org )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorsPublicSettingsRetrieve (String mentor , String org )
→ Future <MentorSettings ? >
Get mentor settings
aiMentorOrgsMentorsPublicSettingsRetrieveWithHttpInfo (String mentor , String org )
→ Future <Response >
Get mentor settings
Get mentor settings
Get mentor settings
Update mentor settings
Update mentor settings
aiMentorOrgsMentorsUsersRetrieve (String mentor , String org , String userId )
→ Future <SessionDetail ? >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorsUsersRetrieveWithHttpInfo (String mentor , String org , String userId )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsPlatformAdmin
aiMentorOrgsMentorWithSettingsCreate (String org , MentorFromTemplateWithSettingRequest mentorFromTemplateWithSettingRequest )
→ Future <Mentor ? >
View to create a mentor from a template with settings
aiMentorOrgsMentorWithSettingsCreateWithHttpInfo (String org , MentorFromTemplateWithSettingRequest mentorFromTemplateWithSettingRequest )
→ Future <Response >
View to create a mentor from a template with settings
aiMentorOrgsPredictiveAnalyticsCreate (String org , PredictiveAnalyticsRequest predictiveAnalyticsRequest )
→ Future <PredictiveAnalyticsResponse ? >
Send data for predictions
aiMentorOrgsPredictiveAnalyticsCreateWithHttpInfo (String org , PredictiveAnalyticsRequest predictiveAnalyticsRequest )
→ Future <Response >
Send data for predictions
aiMentorOrgsSessionsAskCreate (String org , String sessionId , {AskMentorRequest ? askMentorRequest })
→ Future <AskMentorResponse ? >
Send a custom json from langflow to answer a question
aiMentorOrgsSessionsAskCreateWithHttpInfo (String org , String sessionId , {AskMentorRequest ? askMentorRequest })
→ Future <Response >
Send a custom json from langflow to answer a question
aiMentorOrgsSessionsCreate (String org , ChatSessionRequest chatSessionRequest )
→ Future <ChatSessionResponse ? >
Create a new chat session
aiMentorOrgsSessionsCreateWithHttpInfo (String org , ChatSessionRequest chatSessionRequest )
→ Future <Response >
Create a new chat session
aiMentorOrgsSessionsUsersAskCreate (String org , String sessionId , String userId , {AskMentorRequest ? askMentorRequest })
→ Future <AskMentorResponse ? >
Send a custom json from langflow to answer a question
aiMentorOrgsSessionsUsersAskCreateWithHttpInfo (String org , String sessionId , String userId , {AskMentorRequest ? askMentorRequest })
→ Future <Response >
Send a custom json from langflow to answer a question
aiMentorOrgsUsageRetrieve (String org )
→ Future <Usage ? >
View to return the usage summary of a tenant
aiMentorOrgsUsageRetrieveWithHttpInfo (String org )
→ Future <Response >
View to return the usage summary of a tenant
aiMentorOrgsUsersAudioToTextCreate (String org , String userId , AudioToTextRequest audioToTextRequest )
→ Future <AudioToTextResponse ? >
Convert audio to text
aiMentorOrgsUsersAudioToTextCreateWithHttpInfo (String org , String userId , AudioToTextRequest audioToTextRequest )
→ Future <Response >
Convert audio to text
aiMentorOrgsUsersCategoryCreate (String org , String userId , PromptCategory promptCategory )
→ Future <PromptCategory ? >
View to create/retrieve a prompt category Only users with the IsAdminUserOrStudentDRFMixin permission can view the categories Only users with the IsPlatformAdminDRFMixin permission can create categories
aiMentorOrgsUsersCategoryCreateWithHttpInfo (String org , String userId , PromptCategory promptCategory )
→ Future <Response >
View to create/retrieve a prompt category Only users with the IsAdminUserOrStudentDRFMixin permission can view the categories Only users with the IsPlatformAdminDRFMixin permission can create categories
aiMentorOrgsUsersCategoryDestroy (String org , String userId )
→ Future <void >
View to create/retrieve a prompt category Only users with the IsAdminUserOrStudentDRFMixin permission can view the categories Only users with the IsPlatformAdminDRFMixin permission can create categories
aiMentorOrgsUsersCategoryDestroyWithHttpInfo (String org , String userId )
→ Future <Response >
View to create/retrieve a prompt category Only users with the IsAdminUserOrStudentDRFMixin permission can view the categories Only users with the IsPlatformAdminDRFMixin permission can create categories
aiMentorOrgsUsersCategoryRetrieve (String org , String userId )
→ Future <PromptCategory ? >
View to create/retrieve a prompt category Only users with the IsAdminUserOrStudentDRFMixin permission can view the categories Only users with the IsPlatformAdminDRFMixin permission can create categories
aiMentorOrgsUsersCategoryRetrieveWithHttpInfo (String org , String userId )
→ Future <Response >
View to create/retrieve a prompt category Only users with the IsAdminUserOrStudentDRFMixin permission can view the categories Only users with the IsPlatformAdminDRFMixin permission can create categories
aiMentorOrgsUsersCreate (String org , String userId , Mentor mentor )
→ Future <Mentor ? >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersCreateWithHttpInfo (String org , String userId , Mentor mentor )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersDestroy (String name , String org , String userId )
→ Future <void >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersDestroyWithHttpInfo (String name , String org , String userId )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersGuidedPromptsSessionsRetrieve (String org , String sessionId , String userId )
→ Future <GuidedPromptsResponse ? >
Get suggested AI prompts based on chat history
aiMentorOrgsUsersGuidedPromptsSessionsRetrieveWithHttpInfo (String org , String sessionId , String userId )
→ Future <Response >
Get suggested AI prompts based on chat history
aiMentorOrgsUsersList (String org , String userId , {int ? page , int ? pageSize })
→ Future <PaginatedMentorList ? >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersListWithHttpInfo (String org , String userId , {int ? page , int ? pageSize })
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersMentorsRetrieve (String mentor , String org , String userId )
→ Future <Mentor ? >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersMentorsRetrieveWithHttpInfo (String mentor , String org , String userId )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
Suggested Prompts Endpoint
Suggested Prompts Endpoint
Request body {"index": 0}
Request body {"index": 0}
Suggested Prompts Endpoint
Suggested Prompts Endpoint
Suggested Prompts Endpoint
Suggested Prompts Endpoint
aiMentorOrgsUsersPartialUpdate (String name , String org , String userId , {PatchedMentor ? patchedMentor })
→ Future <Mentor ? >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersPartialUpdateWithHttpInfo (String name , String org , String userId , {PatchedMentor ? patchedMentor })
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersPinMessageCreate (String org , String userId , PinnedMessageCreate pinnedMessageCreate )
→ Future <PinnedMessageCreate ? >
View to create/retrieve a pinned message
aiMentorOrgsUsersPinMessageCreateWithHttpInfo (String org , String userId , PinnedMessageCreate pinnedMessageCreate )
→ Future <Response >
View to create/retrieve a pinned message
aiMentorOrgsUsersPinMessageDestroy (String org , String userId )
→ Future <void >
View to create/retrieve a pinned message
aiMentorOrgsUsersPinMessageDestroyWithHttpInfo (String org , String userId )
→ Future <Response >
View to create/retrieve a pinned message
aiMentorOrgsUsersPinMessageRetrieve (String org , String userId )
→ Future <PinnedMessageCreate ? >
View to create/retrieve a pinned message
aiMentorOrgsUsersPinMessageRetrieveWithHttpInfo (String org , String userId )
→ Future <Response >
View to create/retrieve a pinned message
aiMentorOrgsUsersPromptCreate (String org , String userId , Prompt prompt )
→ Future <Prompt ? >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptCreateWithHttpInfo (String org , String userId , Prompt prompt )
→ Future <Response >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptDestroy (int id , String org , String userId )
→ Future <void >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptDestroyWithHttpInfo (int id , String org , String userId )
→ Future <Response >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptList (String org , String userId )
→ Future <List <Prompt > ? >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptListWithHttpInfo (String org , String userId )
→ Future <Response >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptPartialUpdate (int id , String org , String userId , {PatchedPrompt ? patchedPrompt })
→ Future <Prompt ? >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptPartialUpdateWithHttpInfo (int id , String org , String userId , {PatchedPrompt ? patchedPrompt })
→ Future <Response >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptRetrieve (int id , String org , String userId )
→ Future <Prompt ? >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptRetrieveWithHttpInfo (int id , String org , String userId )
→ Future <Response >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptUpdate (int id , String org , String userId , Prompt prompt )
→ Future <Prompt ? >
View to create/retrieve a prompt
aiMentorOrgsUsersPromptUpdateWithHttpInfo (int id , String org , String userId , Prompt prompt )
→ Future <Response >
View to create/retrieve a prompt
aiMentorOrgsUsersRecentMessagesRetrieve (String org , String userId )
→ Future <ChatSessionWithMessage ? >
Paginated view to return recent messages
aiMentorOrgsUsersRecentMessagesRetrieveWithHttpInfo (String org , String userId )
→ Future <Response >
Paginated view to return recent messages
aiMentorOrgsUsersRecommendCoursesRetrieve (String org , String userId , {bool ? includeLearnerSkills , bool ? rankByDifficulty , bool ? returnCourseData , int ? returnNumber , String ? searchTerms })
→ Future <RecommendCourseResponse ? >
Recommend courses for a user
aiMentorOrgsUsersRecommendCoursesRetrieveWithHttpInfo (String org , String userId , {bool ? includeLearnerSkills , bool ? rankByDifficulty , bool ? returnCourseData , int ? returnNumber , String ? searchTerms })
→ Future <Response >
Recommend courses for a user
aiMentorOrgsUsersRetrieve (String name , String org , String userId )
→ Future <Mentor ? >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersRetrieveWithHttpInfo (String name , String org , String userId )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
View to get the sessions of a particular user filterable by start date and end date without pagination
View to get the sessions of a particular user filterable by start date and end date without pagination
Create a new chat session
Create a new chat session
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
View to add the downloadable message for a session
View to add the downloadable message for a session
Get chat messages
Get chat messages
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
Update Chat session details
Update Chat session details
aiMentorOrgsUsersTasksRetrieve (String org , String taskId , String userId )
→ Future <RetrieveTask ? >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersTasksRetrieveWithHttpInfo (String org , String taskId , String userId )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersTasksSessionsCreate (String org , String sessionId , String userId , TaskView taskView )
→ Future <TaskView ? >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersTasksSessionsCreateWithHttpInfo (String org , String sessionId , String userId , TaskView taskView )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersUpdate (String name , String org , String userId , Mentor mentor )
→ Future <Mentor ? >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
aiMentorOrgsUsersUpdateWithHttpInfo (String name , String org , String userId , Mentor mentor )
→ Future <Response >
Mixin that includes the StudentTokenAuthentication and IsAdminUserOrStudent
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
ibl_mobile_core_frontend 0.7.7