aiBotV1BotsBotPartialUpdate method
Future<BotCreate?>
aiBotV1BotsBotPartialUpdate(
- int id,
- String org, {
- PatchedBotCreate? patchedBotCreate,
Create modify and update bot information for a specific tenant.
Parameters:
-
int id (required): A unique integer value identifying this bot.
-
String org (required):
-
PatchedBotCreate patchedBotCreate:
Implementation
Future<BotCreate?> aiBotV1BotsBotPartialUpdate(int id, String org, { PatchedBotCreate? patchedBotCreate, }) async {
final response = await aiBotV1BotsBotPartialUpdateWithHttpInfo(id, org, patchedBotCreate: patchedBotCreate, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'BotCreate',) as BotCreate;
}
return null;
}