aiMathMathSampleQuestionsCreate method
Future<SampleQuestionsDocument?>
aiMathMathSampleQuestionsCreate(
- String org,
- SampleQuestionsDocument sampleQuestionsDocument
Upload documents to provide sample questions of reference to generate more math questions from.
Parameters:
-
String org (required):
-
SampleQuestionsDocument sampleQuestionsDocument (required):
Implementation
Future<SampleQuestionsDocument?> aiMathMathSampleQuestionsCreate(String org, SampleQuestionsDocument sampleQuestionsDocument,) async {
final response = await aiMathMathSampleQuestionsCreateWithHttpInfo(org, sampleQuestionsDocument,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'SampleQuestionsDocument',) as SampleQuestionsDocument;
}
return null;
}