CredentialsApi class
Methods
-
credentialsOrgsAssertionsList(String org, {String? format, int? groupId, int? limit, int? offset})
→ Future<PaginatedAssertionsList?>
-
Endpoint to retrieve the issued credentials for a given tenant
-
credentialsOrgsAssertionsListWithHttpInfo(String org, {String? format, int? groupId, int? limit, int? offset})
→ Future<Response>
-
Endpoint to retrieve the issued credentials for a given tenant
-
credentialsOrgsAssertionsOverTimeRetrieve(String org, {String? endDate, String? format, int? groupId, String? startDate})
→ Future<OverTime?>
-
Get all credentials of a given tenant
-
credentialsOrgsAssertionsOverTimeRetrieveWithHttpInfo(String org, {String? endDate, String? format, int? groupId, String? startDate})
→ Future<Response>
-
Get all credentials of a given tenant
-
credentialsOrgsCourseAssertionsOverTimeRetrieve(String org, {String? endDate, String? format, int? groupId, String? startDate})
→ Future<OverTime?>
-
Get all credentials of a given tenant
-
credentialsOrgsCourseAssertionsOverTimeRetrieveWithHttpInfo(String org, {String? endDate, String? format, int? groupId, String? startDate})
→ Future<Response>
-
Get all credentials of a given tenant
-
credentialsOrgsCourseCredentialsList(String org, {int? limit, int? offset})
→ Future<void>
-
Endpoint to retrieve the credentials of a given tenant
-
credentialsOrgsCourseCredentialsListWithHttpInfo(String org, {int? limit, int? offset})
→ Future<Response>
-
Endpoint to retrieve the credentials of a given tenant
-
credentialsOrgsCredentialsOverTimeRetrieve(String org, {String? endDate, String? format, int? groupId, String? startDate})
→ Future<OverTime?>
-
Get all credentials of a given tenant
-
credentialsOrgsCredentialsOverTimeRetrieveWithHttpInfo(String org, {String? endDate, String? format, int? groupId, String? startDate})
→ Future<Response>
-
Get all credentials of a given tenant
-
credentialsOrgsCredentialsRetrieve(int id, String org)
→ Future<Credential?>
-
Endpoint to retrieve the credentials of a given tenant
-
credentialsOrgsCredentialsRetrieveWithHttpInfo(int id, String org)
→ Future<Response>
-
Endpoint to retrieve the credentials of a given tenant
-
credentialsOrgsList(String org, {int? limit, int? offset})
→ Future<PaginatedCredentialList?>
-
Endpoint to retrieve the credentials of a given tenant
-
credentialsOrgsListWithHttpInfo(String org, {int? limit, int? offset})
→ Future<Response>
-
Endpoint to retrieve the credentials of a given tenant
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited