engagementOrgsCoursesTimeUsersRetrieve method
Time spent by users in a course Query Params course_id e.g course-v1:Org+Course4+Run
Parameters:
Implementation
Future<TimeSpentByUsersInCourse?> engagementOrgsCoursesTimeUsersRetrieve(String courseId, String org, { String? endDate, String? format, int? groupId, int? length, int? page, String? startDate, }) async {
final response = await engagementOrgsCoursesTimeUsersRetrieveWithHttpInfo(courseId, org, endDate: endDate, format: format, groupId: groupId, length: length, page: page, startDate: startDate, );
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'TimeSpentByUsersInCourse',) as TimeSpentByUsersInCourse;
}
return null;
}