perlearnerOrgsUsersCoursesOverviewEngagementIndexRetrieve method
Average of days with atleast an activity within ENGAGEMENT_INDEX_PERIOD consecutive days for a learner in a course
Parameters:
Implementation
Future<Value?> perlearnerOrgsUsersCoursesOverviewEngagementIndexRetrieve(String courseId, String org, String userId,) async {
final response = await perlearnerOrgsUsersCoursesOverviewEngagementIndexRetrieveWithHttpInfo(courseId, org, userId,);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty && response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(await _decodeBodyBytes(response), 'Value',) as Value;
}
return null;
}