RecommendationsApi class
Constructors
- RecommendationsApi([ApiClient? apiClient])
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendationsOrgsUsersRetrieve(
String org, String userId) → Future< RecommendationSearchAPI?> - API endpoint that returns a search api url prepopulated with context data See http://localhost:8000/api/schema/swagger-ui/#/recommendations
-
recommendationsOrgsUsersRetrieveWithHttpInfo(
String org, String userId) → Future< Response> - API endpoint that returns a search api url prepopulated with context data See http://localhost:8000/api/schema/swagger-ui/#/recommendations
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited