ReportStatus class
Constructors
- ReportStatus({String? reportId, String? reportName, StateEnum? state, String? startedOn, String? owner, String? expires, String? url})
- Returns a new ReportStatus instance.
Properties
- expires ↔ String?
-
When report would expire and not available for download anymore
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- owner ↔ String?
-
Report Owner
getter/setter pair
- reportId ↔ String?
-
Used to download the report
getter/setter pair
- reportName ↔ String?
-
Report slug, this is passed when calling the create report endpoint
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedOn ↔ String?
-
Report request timestamp (ISO 8601)
getter/setter pair
- state ↔ StateEnum?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
- url ↔ String?
-
Download link for report when available
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ReportStatus? -
Returns a new ReportStatus instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< ReportStatus> -
mapFromJson(
dynamic json) → Map< String, ReportStatus> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< ReportStatus> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.