TimeDetailData class
Constructors
-
TimeDetailData({required double averageTime, required String displayName, required String id, List<
TimeDetailChild> children = const [], int? totalTime, int? totalUsers}) - Returns a new TimeDetailData instance.
Properties
- averageTime ↔ double
-
Average time spent
getter/setter pair
-
children
↔ List<
TimeDetailChild> -
getter/setter pair
- displayName ↔ String
-
Chapter name
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String
-
Chapter Id
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalTime ↔ int?
-
Total time spent
getter/setter pair
- totalUsers ↔ int?
-
Total users who accessed the chapter
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → TimeDetailData? -
Returns a new TimeDetailData instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< TimeDetailData> -
mapFromJson(
dynamic json) → Map< String, TimeDetailData> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< TimeDetailData> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.