UserChatFeedback class
Constructors
- UserChatFeedback({required int id, required String username, required String session, required String userText, required String aiResponse, required String reason, required String additionalFeedback, required int mentor, RatingEnum? rating})
- Returns a new UserChatFeedback instance.
Properties
- additionalFeedback ↔ String
-
getter/setter pair
- aiResponse ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ int
-
getter/setter pair
- mentor ↔ int
-
getter/setter pair
- rating ↔ RatingEnum?
-
getter/setter pair
- reason ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- session ↔ String
-
getter/setter pair
- username ↔ String
-
getter/setter pair
- userText ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → UserChatFeedback? -
Returns a new UserChatFeedback instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< UserChatFeedback> -
mapFromJson(
dynamic json) → Map< String, UserChatFeedback> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< UserChatFeedback> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.